
/* Generated data (by glib-mkenums) */


#include <glib-object.h>

#include "/usr/src/ports/gcr/gcr-3.20.0-1.x86_64/src/gcr-3.20.0/ui/gcr-collection-model.h"
/* enumerations from "/usr/src/ports/gcr/gcr-3.20.0-1.x86_64/src/gcr-3.20.0/ui/gcr-collection-model.h" */
GType gcr_collection_model_mode_get_type (void) G_GNUC_CONST;

GType
gcr_collection_model_mode_get_type (void)
{
    static GType etype = 0;
    if (G_UNLIKELY(etype == 0)) {
        static const GEnumValue values[] = {
            { GCR_COLLECTION_MODEL_LIST, "GCR_COLLECTION_MODEL_LIST", "list" },
            { GCR_COLLECTION_MODEL_TREE, "GCR_COLLECTION_MODEL_TREE", "tree" },
            { 0, NULL, NULL }
        };
        etype = g_enum_register_static (g_intern_static_string ("GcrCollectionModelMode"), values);
    }
    return etype;
}

 /**/

/* Generated data ends here */

